declare type EventName = 'added to queue' | 'waiting with priority' | 'started processing' | 'finished processing' | 'process failed';
interface IEvent {
    name: EventName;
    timestamp: Date;
    note?: string;
}
declare type ResultFunc<Result, QueueData> = (result: Result, item: QueueData, events: IEvent[]) => void;
declare type QueueInput<QueueItem, FunctionResult> = QueueItem | (() => Promise<FunctionResult>);
export declare class QueueProcessor<QueueData = object | string | number, Result = object | void | unknown> {
    private processFn;
    private queue;
    private runningJobs;
    private concurrent;
    private waiting;
    private handleResult;
    private handleError;
    constructor(processFn: (queueItem: QueueData) => Result | Promise<Result>, options?: {
        handleResult?: ResultFunc<Result, QueueData>;
        handleError?: ResultFunc<any, QueueData>;
        concurrency?: number;
    });
    /**
     * Add an item or a function to a FIFO queue - will be processed when available
     */
    addToQueue(input: QueueInput<QueueData, Result>): void;
    /**
     * Add an item or a function to be processed as soon as possible skipping ahead of queue.
     * This action will not exceed the concurrency limit.
     */
    addRunning(input: QueueInput<QueueData, Result>): Promise<void>;
    /**
     * Add an item or a function to be processed as soon as possible skipping ahead of queue.
     * This action will not exceed the concurrency limit.
     * This function will return a result and may raise exceptions.
     * This function ignores handleResult and handleError in options.
     */
    process(input: QueueInput<QueueData, Result>, handleLogs?: (logs: IEvent[]) => void): Promise<Result>;
    /**
     * Set the amount of concurrent jobs.
     * This action will automatically run new jobs if possible.
     */
    set concurrency(concurrency: number);
    /**
     * Get the amount of concurrent jobs.
     */
    get concurrency(): number;
    /**
     * Awaitable call to make sure queue has been depleted and all running jobs have finished
     */
    finish(): Promise<void>;
    /**
     * Number of currently running jobs
     */
    get running(): number;
    /**
     * Number of items in the queue
     */
    get enqueued(): number;
    /**
     * Number of items to be processed as soon as possible
     */
    get enqueuedWithPriority(): number;
    private createQueueItem;
    private get currentPromises();
    private get canRunProcess();
    private runProcess;
    private runAvailable;
}
export {};
